<?php
/**
 * Aereo functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Aereo
 */

if ( ! function_exists( 'aereo_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function aereo_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Aereo, use a find and replace
		 * to change 'aereo' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'aereo');

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'aereo-content', 1000, 300, true );
		add_image_size( 'aereo-post-thumb', 540 );
		add_image_size( 'aereo-single-thumb', 720 );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'aereo' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'aereo_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_editor_style( get_stylesheet_uri() );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'aereo_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function aereo_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'aereo_content_width', 640 );
}
add_action( 'after_setup_theme', 'aereo_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function aereo_widgets_init() {

	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'aereo' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'aereo' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'aereo_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function aereo_scripts() {

	wp_enqueue_script( 'aereo-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ));
	wp_enqueue_style( 'aereo-bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css');
	wp_enqueue_style( 'aereo-fontawesome', 'https://use.fontawesome.com/releases/v5.7.2/css/all.css' );
	wp_enqueue_style( 'aereo-style', get_stylesheet_uri() );

	// Google Font Style
	wp_enqueue_style( 'aereo-roboto-font', '//fonts.googleapis.com/css?family=Roboto:300,400,500');
	wp_enqueue_style( 'aereo-open_sans-font', '//fonts.googleapis.com/css?family=Open+Sans:400,600,700,800');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'aereo_scripts' );

/**
 * require files
 */
require get_template_directory() . '/inc/customizer.php';

require get_template_directory() . '/inc/custom-header.php';

// Bootstrap Navbar Class Added (Nav-Item Nav-link)
function aereo_nav_responsive($classes, $item, $args) {
    $classes[] = 'nav-item nav-link';
    return $classes;
}
add_filter('nav_menu_css_class','aereo_nav_responsive',1,3);