<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...
 *
 * @package Aereo
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses aereo_header_style()
 * @uses aereo_admin_header_image()
 */
function aereo_custom_header_setup() {
	add_theme_support(
		'custom-header',
		apply_filters(
			'aereo_custom_header_args',
			array(
				'default-image'          => get_template_directory_uri() . '/img/header.jpg',
				'default-text-color'     => 'ffffff',
				'width'                  => 1920,
				'height'                 => 850,
				'flex-height'            => true,
				'wp-head-callback'       => 'aereo_header_style',
				'admin-preview-callback' => 'aereo_admin_header_image',
			)
		)
	);
}
add_action( 'after_setup_theme', 'aereo_custom_header_setup' );

if ( ! function_exists( 'aereo_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog
	 *
	 * @see aereo_custom_header_setup().
	 */
	function aereo_header_style() {
		if ( get_header_image() ) {
			?>
			<style type="text/css">
					.header-main {
						background: url(<?php echo esc_url( get_header_image() ); ?>) no-repeat;
						background-position: center top;
						background-attachment: fixed;
						background-size: cover;
						padding: 120px 0;
						margin-bottom: 60px;
					}
		</style>
		<?php
		}
	}
endif; // aereo_header_style ?>
